/**
 * Copyright (C) 1999-2007  Free Software Foundation, Inc.
 *
 * This file is part of GNU gengetopt 
 *
 * GNU gengetopt is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3, or (at your option) 
 * any later version. 
 *
 * GNU gengetopt is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details. 
 *
 * You should have received a copy of the GNU General Public License along 
 * with gengetopt; see the file COPYING. If not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#ifndef GLOBAL_OPTS_H
#define GLOBAL_OPTS_H

#define HELP_LONG_OPT "help"
#define HELP_SHORT_OPT 'h'
#define HELP_SHORT_OPT_STR "h"
#define HELP_OPT_DESCR "Print help and exit"

#define FULL_HELP_LONG_OPT "full-help"
#define FULL_HELP_LONG_OPT_FIELD "full_help"
#define FULL_HELP_OPT_DESCR "Print help, including hidden options, and exit"

#define DETAILED_HELP_LONG_OPT "detailed-help"
#define DETAILED_HELP_LONG_OPT_FIELD "detailed_help"
#define DETAILED_HELP_OPT_DESCR "Print help, including all details and hidden options, and exit"

#define VERSION_LONG_OPT "version"
#define VERSION_SHORT_OPT 'V'
#define VERSION_SHORT_OPT_STR "V"
#define VERSION_OPT_DESCR "Print version and exit"

#endif /* GLOBAL_OPTS_H */
